"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Handlebars = require("handlebars");
const glob = require("glob");
const path = require("path");
const readHandlebarsTemplate_1 = require("./readHandlebarsTemplate");
const registerHandlebarHelpers_1 = require("./registerHandlebarHelpers");
/**
 * Read all the Handlebar templates that we need and return on wrapper object
 * so we can easily access the templates in out generator / write functions.
 */
function readHandlebarsTemplates() {
    try {
        registerHandlebarHelpers_1.registerHandlebarHelpers();
        const templates = {
            models: readHandlebarsTemplate_1.readHandlebarsTemplate(path.resolve(__dirname, `../../src/templates/models/index.hbs`)),
            model: readHandlebarsTemplate_1.readHandlebarsTemplate(path.resolve(__dirname, `../../src/templates/models/model.hbs`)),
            schemas: readHandlebarsTemplate_1.readHandlebarsTemplate(path.resolve(__dirname, `../../src/templates/schemas/index.hbs`)),
            schema: readHandlebarsTemplate_1.readHandlebarsTemplate(path.resolve(__dirname, `../../src/templates/schemas/schema.hbs`)),
            services: readHandlebarsTemplate_1.readHandlebarsTemplate(path.resolve(__dirname, `../../src/templates/services/index.hbs`)),
            service: readHandlebarsTemplate_1.readHandlebarsTemplate(path.resolve(__dirname, `../../src/templates/services/service.hbs`)),
            settings: readHandlebarsTemplate_1.readHandlebarsTemplate(path.resolve(__dirname, `../../src/templates/core/OpenAPI.hbs`)),
        };
        const partials = path.resolve(__dirname, `../../src/templates//partials`);
        const partialsFiles = glob.sync('*.hbs', { cwd: partials });
        partialsFiles.forEach(partial => {
            Handlebars.registerPartial(path.basename(partial, '.hbs'), readHandlebarsTemplate_1.readHandlebarsTemplate(path.resolve(partials, partial)));
        });
        return templates;
    }
    catch (e) {
        throw new Error(`Could not read Handlebar templates`);
    }
}
exports.readHandlebarsTemplates = readHandlebarsTemplates;
