"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const glob = require("glob");
const mkdirp = require("mkdirp");
const path = require("path");
const rimraf = require("rimraf");
const writeClientModels_1 = require("./writeClientModels");
const writeClientSchemas_1 = require("./writeClientSchemas");
const writeClientServices_1 = require("./writeClientServices");
const writeClientSettings_1 = require("./writeClientSettings");
/**
 * Write our OpenAPI client, using the given templates at the given output path.
 * @param client Client object with all the models, services, etc.
 * @param httpClient The selected httpClient (fetch or XHR).
 * @param templates Templates wrapper with all loaded Handlebars templates.
 * @param outputPath
 */
function writeClient(client, httpClient, templates, outputPath) {
    const outputPathCore = path.resolve(outputPath, 'core');
    const outputPathModels = path.resolve(outputPath, 'models');
    const outputPathSchemas = path.resolve(outputPath, 'schemas');
    const outputPathServices = path.resolve(outputPath, 'services');
    // Clean output directory
    try {
        rimraf.sync(outputPath);
    }
    catch (e) {
        throw new Error(`Could not clean output directory`);
    }
    // Create new directories
    try {
        mkdirp.sync(outputPath);
        mkdirp.sync(outputPathCore);
        mkdirp.sync(outputPathModels);
        mkdirp.sync(outputPathSchemas);
        mkdirp.sync(outputPathServices);
    }
    catch (e) {
        throw new Error(`Could not create output directories`);
    }
    // Copy all support files
    const supportFiles = path.resolve(__dirname, `../../src/templates/`);
    const supportFilesList = glob.sync('**/*.ts', { cwd: supportFiles });
    supportFilesList.forEach(file => {
        fs.copyFileSync(path.resolve(supportFiles, file), // From input path
        path.resolve(outputPath, file) // To output path
        );
    });
    // Write the client files
    writeClientSettings_1.writeClientSettings(client, httpClient, templates, outputPathCore);
    writeClientModels_1.writeClientModels(client.models, templates, outputPathModels);
    writeClientSchemas_1.writeClientSchemas(client.models, templates, outputPathSchemas);
    writeClientServices_1.writeClientServices(client.services, templates, outputPathServices);
}
exports.writeClient = writeClient;
